#' Add .gitignore file suitable for R project
#'
#' @inheritParams utils::download.file
#'
#' @return `NULL`, this function is used for side effect.
#' @export
#'
#' @examples
#' tmpfile <- tempfile()
#' add_gitignore(destfile = tmpfile)
#' readLines(tmpfile)
add_gitignore <- function(url = "https://raw.githubusercontent.com/github/gitignore/main/R.gitignore",
                          destfile = ".gitignore") {
  stopifnot(download.file(url, destfile) == 0)
  header <- add_comment_block("R template from:",
                              url,
                              paste("Downloaded the", Sys.time()))
  s <- readLines(destfile)
  s <- c(header, s)
  writeLines(s, destfile)
}

add_comment <- function(x, comment_tag = "#") {
  paste(comment_tag, x)
}

add_comment_block <- function(..., comment_tag = "#", line_len) {
  x <- list(...)
  c("",
    strrep(comment_tag, 80),
    sapply(x, add_comment, comment_tag = comment_tag),
    strrep(comment_tag, 80),
    "")
}
